শ্রীপুরে অবরোধের সমর্থনে বিএনপির মিছিল – সত্যের সন্ধানে সারাক্ষণ
Description: গাজীপুর: চলমান অবরোধের সমর্থনে গাজীপুর জেলার শ্রীপুরে ঢাকা-ময়মনসিংহ মহাসড়কের নয়নপুরে মিছিল করেছে শ্রীপুর উপজেলা বিএনপি। আজ সোমবার সকালে এই মিছিল হয়। মিছিলে নেতৃত্ব দেন শ্রীপুর উপজেলার বিএনপির সভাপত…
Date: 2023-12-04T08:35:35+00:00

বুধবার, ফেব্রুয়ারি ২১, ২০২৪

# শ্রীপুরে অবরোধের সমর্থনে বিএনপির মিছিল

Slider গ্রাম বাংলা
ডিসেম্বর ৪, ২০২৩ডিসেম্বর ৪, ২০২৩ ষ্টাফ রির্পোটার : গ্রাম বাংলা নিউজ টুয়েন্টিফোর ডটকম Leave a Comment on শ্রীপুরে অবরোধের সমর্থনে বিএনপির মিছিল

গাজীপুর: চলমান অবরোধের সমর্থনে গাজীপুর জেলার শ্রীপুরে ঢাকা-ময়মনসিংহ মহাসড়কের নয়নপুরে মিছিল করেছে শ্রীপুর উপজেলা বিএনপি।

আজ সোমবার সকালে এই মিছিল হয়। মিছিলে নেতৃত্ব দেন শ্রীপুর উপজেলার বিএনপির সভাপতি শাহজাহান ফকির ও সাধারণ সম্পাদক আক্তারুল আলম মাস্টার।

প্রত্যক্ষদর্শীরা জানান, সকাল ৬টার দিকে অবরোধের সমর্থনে অর্ধশত লোকের একটি মিছিল ঢাকা-ময়মনসিংহ মহাসড়কের নয়নপুর এলাকায় বের হয়। মিছিলটি সড়ক প্রদক্ষীন করে রাস্তায় টায়ার জ্বালিয়ে বিক্ষোভ করে। এরপর তারা চলে যায়।

Share on FacebookShare
Share on TwitterTweet
Share on PinterestShare
Share on LinkedInShare
Share on DiggShare

## Related Posts

### খুলনায় থানায় ভেতরে গৃহবধূকে ধর্ষণের অভিযোগ ওসিসহ পাঁচ পুলিশের বিরুদ্ধে

### কেমন আছেন নিবিড়, জানালেন বাবা

### প্রধানমন্ত্রী কে হবেন, খালেদা মুক্তি না পেলে কী হবে?

### Leave a Reply Cancel reply

Your email address will not be published. Required fields are marked *

Comment

Name *

Email *

Website

Notify me of follow-up comments by email.

Notify me of new posts by email.

#### ফেজবোকে আমরা

> ফেজবোকে আমরা

- সাম্প্রতিক
- আলোচিত

### বিএনপি নেতাকে জেটেবের ফৃুলের শুভেচ্ছা

ফেব্রুয়ারি ২০, ২০২৪ ষ্টাফ রির্পোটার : গ্রাম বাংলা নিউজ টুয়েন্টিফোর ডটকম

### সাবেক ভূমিমন্ত্রী সাইফুজ্জামান চৌধুরীর সম্পদের পাহাড় যুক্তরাজ্যে

ফেব্রুয়ারি ২০, ২০২৪ ষ্টাফ রির্পোটার : গ্রাম বাংলা নিউজ টুয়েন্টিফোর ডটকম

### শ্রীপুরে ৮টি ভাংঙ্গা রাস্তা সংস্কার হচ্ছে, প্রতিমন্ত্রীর ছোঁয়ায়

ফেব্রুয়ারি ২০, ২০২৪ ষ্টাফ রির্পোটার : গ্রাম বাংলা নিউজ টুয়েন্টিফোর ডটকম

### আমার আয়সী এখন বাবা পাবে কই!

ফেব্রুয়ারি ২০, ২০২৪ ষ্টাফ রির্পোটার : গ্রাম বাংলা নিউজ টুয়েন্টিফোর ডটকম

### বানিজ্য মেলায় হ্যাট্রিক পুরস্কার পেলো শারীরিক প্রতিবন্ধী সুরক্ষা ট্রাষ্ট

ফেব্রুয়ারি ২০, ২০২৪ ষ্টাফ রির্পোটার : গ্রাম বাংলা নিউজ টুয়েন্টিফোর ডটকম

- Soccer-Manager.eu commented on টঙ্গীর শিশু উন্নয়ন কেন্দ্রের বন্দির মৃত্যু নির্যাতনে মৃত্যুর অভিযোগ পরিবারের: I enjoy what you guys are usually up too. This sor
- Soccer-Manager.eu commented on টঙ্গীর শিশু উন্নয়ন কেন্দ্রের বন্দির মৃত্যু নির্যাতনে মৃত্যুর অভিযোগ পরিবারের: I enjoy what you guys are usually up too. This sor
- csarcom commented on গাইবান্ধার খবর: <a href=http://events.ahovey.est-online.hut2.ru
- newpokimcom commented on গাইবান্ধার খবর: niggers last info about pokimane anal porno
- csgoarcom commented on গাইবান্ধার খবর: cs go <a href=http://bottompics.ahovey.est-onli

####

#### আর্কাইভ ক্যালেন্ডার